@@ -9,13 +9,17 @@ from qtpy import QtCore
 
 from prettyqt import core
 
+OPEN_MODES = core.iodevice.OPEN_MODES
 
 QtCore.QBuffer.__bases__ = (core.IODevice,)
 
 
 class Buffer(QtCore.QBuffer):
+
     @contextlib.contextmanager
-    def open_file(self, flags):
-        self.open(flags)
+    def open_file(self, flag):
+        if flag in OPEN_MODES:
+            flag = OPEN_MODES[flag]
+        self.open(flag)
         yield None
         self.close()
