@@ -12,13 +12,6 @@ QtWidgets.QStackedLayout.__bases__ = (widgets.Layout,)
 
 class StackedLayout(QtWidgets.QStackedLayout):
 
-    def __getitem__(self, index):
-        item = self.itemAt(index)
-        widget = item.widget()
-        if widget is None:
-            widget = item.layout()
-        return widget
-
     def __getstate__(self):
         return dict(items=self.get_children())
 
@@ -30,9 +23,6 @@ class StackedLayout(QtWidgets.QStackedLayout):
     def __iter__(self):
         return iter(self.get_children())
 
-    def __len__(self):
-        return self.count()
-
     def __add__(self, other):
         if isinstance(other, (QtWidgets.QWidget, QtWidgets.QLayout)):
             self.add(other)
