@@ -3,6 +3,8 @@
 @author: Philipp Temminghoff
 """
 
+import contextlib
+
 from qtpy import QtWidgets
 
 from prettyqt import gui, core, widgets
@@ -19,9 +21,6 @@ class TextEdit(QtWidgets.QTextEdit):
         super().__init__(*args, **kwargs)
         self.textChanged.connect(self.on_value_change)
 
-    def on_value_change(self):
-        self.value_changed.emit(self.text())
-
     def __getstate__(self):
         return dict(text=self.text(),
                     enabled=self.isEnabled(),
@@ -38,6 +37,15 @@ class TextEdit(QtWidgets.QTextEdit):
             self.append_text(other)
             return self
 
+    def on_value_change(self):
+        self.value_changed.emit(self.text())
+
+    @contextlib.contextmanager
+    def create_cursor(self):
+        cursor = gui.TextCursor(self.document())
+        yield cursor
+        self.setTextCursor(cursor)
+
     def set_text(self, text: str):
         self.setPlainText(text)
 
@@ -47,6 +55,10 @@ class TextEdit(QtWidgets.QTextEdit):
     def text(self) -> str:
         return self.toPlainText()
 
+    def select_text(self, start: int, end: int):
+        with self.create_cursor() as c:
+            c.select_text(start, end)
+
     def set_read_only(self, value: bool = True):
         self.setReadOnly(value)
 
