@@ -5,6 +5,8 @@
 
 from contextlib import contextmanager
 from typing import Callable, Dict, Optional
+import operator
+import functools
 
 from qtpy import QtCore, QtGui, QtWidgets
 
@@ -22,6 +24,42 @@ MODALITIES = bidict(window=QtCore.Qt.WindowModal,
                     application=QtCore.Qt.ApplicationModal,
                     none=QtCore.Qt.NonModal)
 
+CURSOR_SHAPES = bidict(arrow=QtCore.Qt.ArrowCursor,
+                       uparrow=QtCore.Qt.UpArrowCursor,
+                       cross=QtCore.Qt.CrossCursor,
+                       wait=QtCore.Qt.WaitCursor,
+                       caret=QtCore.Qt.IBeamCursor,
+                       size_vertical=QtCore.Qt.SizeVerCursor,
+                       size_horizonal=QtCore.Qt.SizeHorCursor,
+                       size_topright=QtCore.Qt.SizeBDiagCursor,
+                       size_topleft=QtCore.Qt.SizeFDiagCursor,
+                       size_all=QtCore.Qt.SizeAllCursor,
+                       blank=QtCore.Qt.BlankCursor,
+                       split_vertical=QtCore.Qt.SplitVCursor,
+                       split_horizontal=QtCore.Qt.SplitHCursor,
+                       pointing_hand=QtCore.Qt.PointingHandCursor,
+                       forbidden=QtCore.Qt.ForbiddenCursor,
+                       open_hand=QtCore.Qt.OpenHandCursor,
+                       closed_hand=QtCore.Qt.ClosedHandCursor,
+                       whats_this=QtCore.Qt.WhatsThisCursor,
+                       busy=QtCore.Qt.BusyCursor,
+                       drag_move=QtCore.Qt.DragMoveCursor,
+                       drag_copy=QtCore.Qt.DragCopyCursor,
+                       drag_link=QtCore.Qt.DragLinkCursor,
+                       bitmap=QtCore.Qt.BitmapCursor)
+
+FOCUS_POLICIES = bidict(tab=QtCore.Qt.TabFocus,
+                        click=QtCore.Qt.ClickFocus,
+                        strong=QtCore.Qt.StrongFocus,
+                        wheel=QtCore.Qt.WheelFocus,
+                        none=QtCore.Qt.NoFocus)
+
+WINDOW_FLAGS = bidict(frameless=QtCore.Qt.FramelessWindowHint,
+                      popup=QtCore.Qt.Popup,
+                      stay_on_top=QtCore.Qt.WindowStaysOnTopHint,
+                      tool=QtCore.Qt.Tool,
+                      window_title=QtCore.Qt.WindowTitleHint,
+                      customize_window=QtCore.Qt.CustomizeWindowHint)
 
 QtWidgets.QWidget.__bases__ = (core.Object, QtGui.QPaintDevice)
 
@@ -97,6 +135,35 @@ class Widget(QtWidgets.QWidget):
         self.setFont(font)
         return font
 
+    def set_window_flags(self, *flags: str, append: bool = False):
+        for flag in flags:
+            if flag not in WINDOW_FLAGS:
+                raise ValueError("Invalid window flag")
+        flags = functools.reduce(operator.ior, [WINDOW_FLAGS[t] for t in flags])
+        if append:
+            flags = flags | self.windowFlags()
+        self.setWindowFlags(flags)
+
+    def set_flags(self,
+                  minimize: Optional[bool] = None,
+                  maximize: Optional[bool] = None,
+                  close: Optional[bool] = None,
+                  stay_on_top: Optional[bool] = None,
+                  frameless: Optional[bool] = None,
+                  window: Optional[bool] = None):
+        if minimize is not None:
+            self.setWindowFlag(QtCore.Qt.WindowMinimizeButtonHint, minimize)
+        if maximize is not None:
+            self.setWindowFlag(QtCore.Qt.WindowMaximizeButtonHint, maximize)
+        if close is not None:
+            self.setWindowFlag(QtCore.Qt.WindowCloseButtonHint, close)
+        if stay_on_top is not None:
+            self.setWindowFlag(QtCore.Qt.WindowStaysOnTopHint, stay_on_top)
+        if frameless is not None:
+            self.setWindowFlag(QtCore.Qt.FramelessWindowHint, frameless)
+        if window is not None:
+            self.setWindowFlag(QtCore.Qt.Window, window)
+
     def set_modality(self, modality: str = "window"):
         """set modality for the dialog
 
@@ -161,7 +228,7 @@ class Widget(QtWidgets.QWidget):
         pol.setVerticalStretch(qpol.verticalStretch())
         return pol
 
-    def set_color(self, color):
+    def set_background_color(self, color):
         self.setStyleSheet(f"background-color: {color};")
 
     def set_stylesheet(self, item, dct: Dict[str, str]) -> str:
@@ -234,6 +301,21 @@ class Widget(QtWidgets.QWidget):
                 return True
         return False
 
+    def set_cursor(self, cursor: str):
+        if cursor not in CURSOR_SHAPES:
+            raise ValueError(f"Invalid cursor '{cursor}'. "
+                             f"Valid values: {CURSOR_SHAPES.keys()}")
+        self.setCursor(CURSOR_SHAPES[cursor])
+
+    def set_focus_policy(self, policy: str):
+        if policy not in FOCUS_POLICIES:
+            raise ValueError(f"Invalid policy '{policy}'. "
+                             f"Valid values: {FOCUS_POLICIES.keys()}")
+        self.setFocusPolicy(FOCUS_POLICIES[policy])
+
+    def get_focus_policy(self) -> str:
+        return FOCUS_POLICIES.inv[self.focusPolicy()]
+
 
 if __name__ == "__main__":
     app = QtWidgets.QApplication([])
