@@ -339,6 +339,9 @@ def test_headerview():
         header.resize_mode("test")
     header.resize_sections("interactive")
     header.set_contextmenu_policy("custom")
+    header.set_default_section_size(None)
+    header.set_default_section_size(30)
+    header.stretch_last_section()
     with pytest.raises(ValueError):
         header.set_contextmenu_policy("test")
     assert header.get_contextmenu_policy() == "custom"
@@ -347,7 +350,7 @@ def test_headerview():
     assert header.section_labels() == ['Name', 'Size', 'Type', 'Date Modified']
     header.save_state()
     header.load_state()
-    header.change_section_vis(0, True)
+    header.set_section_hidden(0, True)
 
 
 def test_keysequenceedit():
@@ -551,7 +554,12 @@ def test_messagebox():
 
 
 def test_plaintextedit():
-    widget = widgets.PlainTextEdit()
+    widget = widgets.PlainTextEdit("This is a test")
+    with widget.create_cursor() as c:
+        c.select_text(2, 4)
+    with widget.current_cursor() as c:
+        c.select_text(2, 4)
+    widget.select_text(2, 4)
     widget.set_text("hallo")
     widget.set_disabled()
     widget.set_enabled()
@@ -567,12 +575,16 @@ def test_plaintextedit():
     widget.set_wrap_mode("anywhere")
     with pytest.raises(ValueError):
         widget.set_wrap_mode("test")
+    widget.set_line_wrap_mode("widget_width")
+    with pytest.raises(ValueError):
+        widget.set_line_wrap_mode("test")
     assert widget.get_value() == "test"
     widget += "append"
     with open("data.pkl", "wb") as jar:
         pickle.dump(widget, jar)
     with open("data.pkl", "rb") as jar:
         widget = pickle.load(jar)
+    widget.set_regex_validator("[0-9]")
 
 
 def test_progressbar():
@@ -738,7 +750,7 @@ def test_tabwidget():
     widget = widgets.TabWidget(detachable=True)
     widget.add_tab(widgets.Widget(), "mdi.timer", show=True)
     widget.set_document_mode(True)
-    widget.insert_tab(0, widgets.Widget(), "test", "mdi.timer", show=True)
+    widget.add_tab(widgets.Widget(), "test", "mdi.timer", position=0, show=True)
     assert len(widget) == 2
     w = widgets.Widget()
     widget.add_tab(w, "test", "mdi.timer")
@@ -771,6 +783,9 @@ def test_textbrowser():
 def test_textedit():
     widget = widgets.TextEdit()
     widget.set_text("test")
+    with widget.create_cursor() as c:
+        c.select_text(1, 3)
+    widget.select_text(1, 3)
     widget.append_text(" this")
     assert widget.text() == "test\n this"
     widget.set_font("Consolas")
@@ -778,7 +793,7 @@ def test_textedit():
     widget.set_read_only()
     widget.scroll_to_bottom()
     widget.set_disabled()
-    widget.set_color("black")
+    widget.set_background_color("black")
     widget.set_text_color("red")
     with open("data.pkl", "wb") as jar:
         pickle.dump(widget, jar)
@@ -809,6 +824,8 @@ def test_toolbar():
     widget.add_menu_button("test,", "mdi.timer", menu=widgets.Menu())
     widget.set_style("icon")
     widget.set_style(None)
+    widget.add_separator("Test")
+    widget.add_separator()
     assert widget.get_style() == "icon"
     widget.set_font_size(10)
     widget.set_enabled()
@@ -832,12 +849,16 @@ def test_toolbutton():
         widget = pickle.load(jar)
     widget.set_enabled()
     widget.set_shortcut("Ctrl+A")
+    widget.set_icon_size(20)
     with pytest.raises(ValueError):
         widget.set_popup_mode("test")
     assert widget.get_popup_mode() == "delayed"
     with pytest.raises(ValueError):
         widget.set_arrow_type("test")
     widget.set_arrow_type("left")
+    with pytest.raises(ValueError):
+        widget.set_style("test")
+    widget.set_style("text_below_icon")
     assert widget.get_arrow_type() == "left"
     menu = widgets.Menu()
     act = widgets.Action()
@@ -995,6 +1016,13 @@ def test_treewidgetitem():
 def test_widget():
     widget = widgets.Widget()
     widget.set_tooltip("test")
+    widget.set_cursor("caret")
+    with pytest.raises(ValueError):
+        widget.set_cursor("test")
+    widget.set_focus_policy("strong")
+    assert widget.get_focus_policy() == "strong"
+    with pytest.raises(ValueError):
+        widget.set_focus_policy("test")
     layout = widgets.BoxLayout()
     widget.set_layout(layout)
     with open("data.pkl", "wb") as jar:
